﻿///////////////////////////////////////////////////////////////////////////////
//
// (C) 2015 ICE TEA GROUP LLC - ALL RIGHTS RESERVED
//
// 
//
// ALL INFORMATION CONTAINED HEREIN IS, AND REMAINS
// THE PROPERTY OF ICE TEA GROUP LLC AND ITS SUPPLIERS, IF ANY.
// THE INTELLECTUAL PROPERTY AND TECHNICAL CONCEPTS CONTAINED
// HEREIN ARE PROPRIETARY TO ICE TEA GROUP LLC AND ITS SUPPLIERS
// AND MAY BE COVERED BY U.S. AND FOREIGN PATENTS, PATENT IN PROCESS, AND
// ARE PROTECTED BY TRADE SECRET OR COPYRIGHT LAW.
//
// DISSEMINATION OF THIS INFORMATION OR REPRODUCTION OF THIS MATERIAL
// IS STRICTLY FORBIDDEN UNLESS PRIOR WRITTEN PERMISSION IS OBTAINED
// FROM ICE TEA GROUP LLC.
//
///////////////////////////////////////////////////////////////////////////////

using System;
using Wisej.Core;
using System.Drawing;

namespace Wisej.Web.Ext.FullCalendar
{
	/// <summary>
	/// Represents the method that will handle the <see cref="E:Wisej.Web.Ext.FullCalendar.FullCalendar.ItemDrop" /> event 
	/// in a <see cref="T:Wisej.Web.Ext.FullCalendar.FullCalendar"/> control.
	/// </summary>
	/// <param name="sender">The source of the event. </param>
	/// <param name="e">A <see cref="T:Wisej.Web.Ext.FullCalendar.ItemDropEventArgs" /> that contains the event data. </param>
	public delegate void ItemDropEventHandler(object sender, ItemDropEventArgs e);

	/// <summary>
	/// Provides data for the <see cref="E:Wisej.Web.Ext.FullCalendar.FullCalendar.ItemDrop" /> event of 
	/// the <see cref="T:Wisej.Web.Ext.FullCalendar.FullCalendar" /> control.
	/// </summary>
	public class ItemDropEventArgs : DayClickEventArgs
	{
		/// <summary>
		///  Constructs a new instance of <see cref="T:Wisej.Web.Ext.FullCalendar.ItemDropEventArgs"/>.
		/// </summary>
		/// <param name="item">The <see cref="T:Wisej.Web.Control"/> that is being dropped.</param>
		/// <param name="day">The day/time that was clicked by the user.</param>
		/// <param name="location">The location of a pointer click, in pixels.</param>
		internal ItemDropEventArgs(Control item, DateTime day, Point location)
			: base(day, MouseButtons.Left, location)
		{
			this.Item = item;
		}

		/// <summary>
		/// Returns the <see cref="T:Wisej.Web.Control"/> that is being dropped on the <see cref="T:Wisej.Web.Ext.FullCalendar.FullCalendar"/>.
		/// </summary>
		/// <returns>The <see cref="T:Wisej.Web.Control"/> that is being dropped.</returns>
		public Control Item
		{
			get;
			private set;
		}

	}
}
